==> mpd_0.21.5.orig.tar.xz: mpd-0.21.5/src/input/LocalOpen.cxx <==
/*
 * Copyright 2003-2018 The Music Player Daemon Project
 * http://www.musicpd.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include "LocalOpen.hxx"
#include "InputStream.hxx"
#include "plugins/FileInputPlugin.hxx"
#include "config.h"

#ifdef ENABLE_ARCHIVE
#include "plugins/ArchiveInputPlugin.hxx"
#endif

#include "fs/Path.hxx"
#include "system/Error.hxx"

#include <assert.h>

InputStreamPtr
OpenLocalInputStream(Path path, Mutex &mutex)
{
	InputStreamPtr is;

#ifdef ENABLE_ARCHIVE
	try {
#endif
		is = OpenFileInputStream(path, mutex);
#ifdef ENABLE_ARCHIVE
	} catch (const std::system_error &e) {
		if (IsPathNotFound(e)) {
			/* ENOTDIR means this may be a path inside an archive
			   file */
			is = OpenArchiveInputStream(path, mutex);
			if (!is)
				throw;
		} else
			throw;
	}
#endif

	assert(is);
	assert(is->IsReady());

	return is;
}

==> mpd-0.22.3.tar.xz: mpd-0.22.3/src/input/LocalOpen.cxx <==
/*
 * Copyright 2003-2020 The Music Player Daemon Project
 * http://www.musicpd.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

#include "LocalOpen.hxx"
#include "InputStream.hxx"
#include "plugins/FileInputPlugin.hxx"
#include "config.h"

#include "io/uring/Features.h"
#ifdef HAVE_URING
#include "plugins/UringInputPlugin.hxx"
#endif

#ifdef ENABLE_ARCHIVE
#include "plugins/ArchiveInputPlugin.hxx"
#endif

#include "fs/Path.hxx"
#include "system/Error.hxx"

#include <cassert>

InputStreamPtr
OpenLocalInputStream(Path path, Mutex &mutex)
{
	InputStreamPtr is;

#ifdef ENABLE_ARCHIVE
	try {
#endif
#ifdef HAVE_URING
		is = OpenUringInputStream(path.c_str(), mutex);
		if (is)
			return is;
#endif

		is = OpenFileInputStream(path, mutex);
#ifdef ENABLE_ARCHIVE
	} catch (const std::system_error &e) {
		if (IsPathNotFound(e)) {
			/* ENOTDIR means this may be a path inside an archive
			   file */
			is = OpenArchiveInputStream(path, mutex);
			if (!is)
				throw;
		} else
			throw;
	}
#endif

	assert(is);
	assert(is->IsReady());

	return is;
}
